@@ -76,7 +76,7 @@ class Qiniu(BackendBase):
                             for chunk in response.iter_bytes():
                                 f.write(chunk)
                     else:
-                        raise DataError()
+                        raise ValueError()
                 return True, download_path
         except Exception as e:
             if tries >= 3:
@@ -99,7 +99,7 @@ class Qiniu(BackendBase):
                                     break
                                 await f.write(chunk)
                     else:
-                        raise DataError()
+                        raise ValueError()
             return True, download_path
         except Exception as e:
             return False, str(e)
