@@ -1,3 +1,4 @@
+import asyncio
 import traceback
 import numpy as np
 import httpx
@@ -7,7 +8,6 @@ from nos import Client
 from nos.transport import Transport
 
 from hamunafs.backends.base import BackendBase
-from aiofile import AIOFile, Writer, async_open
 
 class WYSF(BackendBase):
     def __init__(self, cfg):
@@ -17,7 +17,7 @@ class WYSF(BackendBase):
         self.default_bucket = default_bucket
 
     def get_token(self, filename):
-        return self.auth.upload_token(self.default_bucket, filename)
+        return ''
     
     def geturl(self, entrypoint):
         bucket, bucket_name = entrypoint.split('/')
@@ -109,5 +109,44 @@ class WYSF(BackendBase):
         except Exception as e:
             return False, str(e)
 
+    async def cleanup_old_files(self):
+        objects = self.client.list_objects(self.default_bucket, prefix='tmp_file', limit=1000)
+        keys = [object_list.find("Key").text for object_list in objects["response"].findall("Contents")]
+        try:
+            self.client.delete_objects(self.default_bucket, keys, quiet=False)
+        except:
+            pass
+
+        while len(keys) == 1000:
+            print('listing objects...')
+            objects = self.client.list_objects(self.default_bucket, prefix='tmp_file', limit=1000)
+            keys = [object_list.find("Key").text for object_list in objects["response"].findall("Contents")]
+
+            print('deleting objects...')
+            try:
+                self.client.delete_objects(self.default_bucket, keys, quiet=False)
+            except:
+                pass
+        
+        if len(keys) > 0:
+            print('deleting objects...')
+            try:
+                self.client.delete_objects(self.default_bucket, keys, quiet=True)
+            except:
+                pass
+
+        print('all deleting process done')
+
+
+
+if __name__ == '__main__':
+    client = WYSF({
+        'key': '46b5e0508a9641a485c6d3f62078e7ab',
+        'secret': 'fd187963fb8943febc2624e1241081ed',
+        'domain': 'hamuna-images.nos-eastchina1.126.net',
+        'default_bucket': 'hamuna-images'
+    })
+    asyncio.get_event_loop().run_until_complete(client.cleanup_old_files())
+
 
             
