@@ -172,11 +172,8 @@ class Client(Singleton):
             url = '{}://{}'.format(prefix, e)
             return True, url
         else:
-            if tries > 3:
-                return False, None
-            else:
-                ignore_prefix.append(prefix)
-                return self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
+            ignore_prefix.append(prefix)
+            return self.__put_to_cloud(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
             
     def put_to_cloud(self, path, bucket, bucket_name, tmp=True):
         cache_key = 'cloud_{}_{}'.format(bucket, bucket_name)
@@ -200,11 +197,8 @@ class Client(Singleton):
             url = '{}://{}'.format(prefix, e)
             return True, url
         else:
-            if tries > 3:
-                return False, None
-            else:
-                ignore_prefix.append(prefix)
-                return await self.__put_to_cloud_async(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
+            ignore_prefix.append(prefix)
+            return await self.__put_to_cloud_async(path, bucket, bucket_name, tmp, tries+1, ignore_prefix=ignore_prefix)
 
         
     async def put_to_cloud_async(self, path, bucket, bucket_name, tmp=True):
